==> hapi-fhir-structures-dstu3-2.4-sources.jar: org/hl7/fhir/dstu3/model/codesystems/OperationalStatusEnumFactory.java <==
package org.hl7.fhir.dstu3.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Mon, Apr 17, 2017 17:38-0400 for FHIR v3.0.1


import org.hl7.fhir.dstu3.model.EnumFactory;

public class OperationalStatusEnumFactory implements EnumFactory<OperationalStatus> {

  public OperationalStatus fromCode(String codeString) throws IllegalArgumentException {
    if (codeString == null || "".equals(codeString))
      return null;
    if ("off".equals(codeString))
      return OperationalStatus.OFF;
    if ("on".equals(codeString))
      return OperationalStatus.ON;
    if ("not-ready".equals(codeString))
      return OperationalStatus.NOTREADY;
    if ("standby".equals(codeString))
      return OperationalStatus.STANDBY;
    if ("transduc-discon".equals(codeString))
      return OperationalStatus.TRANSDUCDISCON;
    if ("hw-discon".equals(codeString))
      return OperationalStatus.HWDISCON;
    if ("entered-in-error".equals(codeString))
      return OperationalStatus.ENTEREDINERROR;
    throw new IllegalArgumentException("Unknown OperationalStatus code '"+codeString+"'");
  }

  public String toCode(OperationalStatus code) {
    if (code == OperationalStatus.OFF)
      return "off";
    if (code == OperationalStatus.ON)
      return "on";
    if (code == OperationalStatus.NOTREADY)
      return "not-ready";
    if (code == OperationalStatus.STANDBY)
      return "standby";
    if (code == OperationalStatus.TRANSDUCDISCON)
      return "transduc-discon";
    if (code == OperationalStatus.HWDISCON)
      return "hw-discon";
    if (code == OperationalStatus.ENTEREDINERROR)
      return "entered-in-error";
    return "?";
  }

    public String toSystem(OperationalStatus code) {
      return code.getSystem();
      }

}

==> hapi-fhir-structures-dstu3-3.7.0-sources.jar: org/hl7/fhir/dstu3/model/codesystems/OperationalStatusEnumFactory.java <==
package org.hl7.fhir.dstu3.model.codesystems;

/*
  Copyright (c) 2011+, HL7, Inc.
  All rights reserved.
  
  Redistribution and use in source and binary forms, with or without modification, 
  are permitted provided that the following conditions are met:
  
   * Redistributions of source code must retain the above copyright notice, this 
     list of conditions and the following disclaimer.
   * Redistributions in binary form must reproduce the above copyright notice, 
     this list of conditions and the following disclaimer in the documentation 
     and/or other materials provided with the distribution.
   * Neither the name of HL7 nor the names of its contributors may be used to 
     endorse or promote products derived from this software without specific 
     prior written permission.
  
  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND 
  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. 
  IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT 
  NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR 
  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, 
  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
  POSSIBILITY OF SUCH DAMAGE.
  
*/

// Generated on Sat, Mar 25, 2017 21:03-0400 for FHIR v3.0.0


import org.hl7.fhir.dstu3.model.EnumFactory;

public class OperationalStatusEnumFactory implements EnumFactory<OperationalStatus> {

  public OperationalStatus fromCode(String codeString) throws IllegalArgumentException {
    if (codeString == null || "".equals(codeString))
      return null;
    if ("off".equals(codeString))
      return OperationalStatus.OFF;
    if ("on".equals(codeString))
      return OperationalStatus.ON;
    if ("not-ready".equals(codeString))
      return OperationalStatus.NOTREADY;
    if ("standby".equals(codeString))
      return OperationalStatus.STANDBY;
    if ("transduc-discon".equals(codeString))
      return OperationalStatus.TRANSDUCDISCON;
    if ("hw-discon".equals(codeString))
      return OperationalStatus.HWDISCON;
    if ("entered-in-error".equals(codeString))
      return OperationalStatus.ENTEREDINERROR;
    throw new IllegalArgumentException("Unknown OperationalStatus code '"+codeString+"'");
  }

  public String toCode(OperationalStatus code) {
    if (code == OperationalStatus.OFF)
      return "off";
    if (code == OperationalStatus.ON)
      return "on";
    if (code == OperationalStatus.NOTREADY)
      return "not-ready";
    if (code == OperationalStatus.STANDBY)
      return "standby";
    if (code == OperationalStatus.TRANSDUCDISCON)
      return "transduc-discon";
    if (code == OperationalStatus.HWDISCON)
      return "hw-discon";
    if (code == OperationalStatus.ENTEREDINERROR)
      return "entered-in-error";
    return "?";
  }

    public String toSystem(OperationalStatus code) {
      return code.getSystem();
      }

}
